pub struct PubkyClient;Implementations
Sourceimpl PubkyClient
impl PubkyClient
pub async fn initialise(testnet: bool) -> Result<(), PubkyClientError>
Sourcepub async fn init_from_client(client: Client) -> Result<(), PubkyClientError>
pub async fn init_from_client(client: Client) -> Result<(), PubkyClientError>
Initializes the PUBKY_CONNECTOR_SINGLETON with a provided Client instance.
Usage:
- This function is primarily intended for watcher tests where a controlled
Clientinstance needs to be injected instead of relying on environment-based initialization