pub struct ImageProcessor;Trait Implementations
Sourceimpl VariantProcessor for ImageProcessor
impl VariantProcessor for ImageProcessor
type ProcessingOptions = ImageOptions
Sourcefn get_valid_variants_for_content_type(_content_type: &str) -> Vec<FileVariant>
fn get_valid_variants_for_content_type(_content_type: &str) -> Vec<FileVariant>
Returns a list of valid variants for a given content type
If there are no valid variants for the content type, return an empty list
Sourcefn get_content_type_for_variant(
file: &FileDetails,
variant: &FileVariant,
) -> String
fn get_content_type_for_variant( file: &FileDetails, variant: &FileVariant, ) -> String
Returns the content type for a given variant
Sourcefn get_options_for_variant(
file: &FileDetails,
variant: &FileVariant,
) -> Result<ImageOptions, DynError>
fn get_options_for_variant( file: &FileDetails, variant: &FileVariant, ) -> Result<ImageOptions, DynError>
Returns the processing options for a given variant
If there are no options for this variant, return an error
Sourcefn process<'life0, 'life1, 'life2, 'async_trait>(
origin_file_path: &'life0 str,
output_file_path: &'life1 str,
options: &'life2 ImageOptions,
) -> Pin<Box<dyn Future<Output = Result<String, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn process<'life0, 'life1, 'life2, 'async_trait>(
origin_file_path: &'life0 str,
output_file_path: &'life1 str,
options: &'life2 ImageOptions,
) -> Pin<Box<dyn Future<Output = Result<String, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Processes the origin file and saves the output to the output_file_path based on the passed options
Returns the content type of the processed file or the original content type if no processing was done
Sourcefn create_variant<'life0, 'life1, 'async_trait>(
file: &'life0 FileDetails,
variant: &'life1 FileVariant,
file_path: PathBuf,
) -> Pin<Box<dyn Future<Output = Result<String, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn create_variant<'life0, 'life1, 'async_trait>(
file: &'life0 FileDetails,
variant: &'life1 FileVariant,
file_path: PathBuf,
) -> Pin<Box<dyn Future<Output = Result<String, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Creates a variant for the given file
If there are no options for this variant, return with the original content type