VideoProcessor

Struct VideoProcessor 

pub struct VideoProcessor;
VideoProcessor is just a prototype and not a real implementation when we decide to actual start video processing we will need to implement this.