pub struct PostCounts {
pub tags: u32,
pub unique_tags: u32,
pub replies: u32,
pub reposts: u32,
}Expand description
Represents total counts of relationships of a user.
Fields
replies: u32reposts: u32Implementations
Sourceimpl PostCounts
impl PostCounts
Sourcepub async fn get_by_id(
author_id: &str,
post_id: &str,
) -> Result<Option<PostCounts>, DynError>
pub async fn get_by_id( author_id: &str, post_id: &str, ) -> Result<Option<PostCounts>, DynError>
Retrieves counts by user ID, first trying to get from Redis, then from Neo4j if not found.
pub async fn get_from_index( author_id: &str, post_id: &str, ) -> Result<Option<PostCounts>, DynError>
Sourcepub async fn get_from_graph(
author_id: &str,
post_id: &str,
) -> Result<Option<(PostCounts, bool)>, DynError>
pub async fn get_from_graph( author_id: &str, post_id: &str, ) -> Result<Option<(PostCounts, bool)>, DynError>
Retrieves the counts from Neo4j.
pub async fn put_to_index( &self, author_id: &str, post_id: &str, is_reply: bool, ) -> Result<(), DynError>
Sourcepub async fn update_index_field(
index_key: &[&str],
field: &str,
action: JsonAction,
tag_label: Option<&str>,
) -> Result<(), DynError>
pub async fn update_index_field( index_key: &[&str], field: &str, action: JsonAction, tag_label: Option<&str>, ) -> Result<(), DynError>
Updates a specified JSON field in the index
Arguments
index_key- A slice of string references representing the index key parts.field- The name of the JSON field to be updated.action- The action to perform on the JSON field (increment or decrement).tag_label- An optional tag label used to check membership in a sorted set. Important field to update the unique_tags field
pub async fn reindex(author_id: &str, post_id: &str) -> Result<(), DynError>
pub async fn delete( author_id: &str, post_id: &str, remove_from_feeds: bool, ) -> Result<(), DynError>