pub struct PostStream(pub Vec<PostView>);Tuple Fields
0: Vec<PostView>Implementations
Sourceimpl PostStream
impl PostStream
pub fn extend(&mut self, post_stream: PostStream)
pub async fn get_posts( source: StreamSource, pagination: Pagination, order: SortOrder, sorting: StreamSorting, viewer_id: Option<String>, tags: Option<Vec<String>>, kind: Option<PubkyAppPostKind>, ) -> Result<Option<Self>, DynError>
pub async fn get_global_posts_keys( sorting: StreamSorting, order: SortOrder, start: Option<f64>, end: Option<f64>, skip: Option<usize>, limit: Option<usize>, ) -> Result<Vec<String>, DynError>
pub async fn get_posts_keys_by_tag( label: &str, sorting: StreamSorting, start: Option<f64>, end: Option<f64>, skip: Option<usize>, limit: Option<usize>, ) -> Result<Vec<String>, DynError>
pub async fn get_posts_by_source( source: StreamSource, order: SortOrder, start: Option<f64>, end: Option<f64>, skip: Option<usize>, limit: Option<usize>, ) -> Result<Vec<String>, DynError>
pub async fn get_bookmarked_posts( user_id: &str, order: SortOrder, start: Option<f64>, end: Option<f64>, skip: Option<usize>, limit: Option<usize>, ) -> Result<Vec<String>, DynError>
pub async fn get_post_replies( author_id: &str, post_id: &str, order: SortOrder, start: Option<f64>, end: Option<f64>, skip: Option<usize>, limit: Option<usize>, ) -> Result<Vec<String>, DynError>
pub async fn from_listed_post_ids( viewer_id: Option<String>, post_keys: &[String], ) -> Result<Option<Self>, DynError>
Sourcepub async fn add_to_timeline_sorted_set(
details: &PostDetails,
) -> Result<(), DynError>
pub async fn add_to_timeline_sorted_set( details: &PostDetails, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn remove_from_timeline_sorted_set(
author_id: &str,
post_id: &str,
) -> Result<(), DynError>
pub async fn remove_from_timeline_sorted_set( author_id: &str, post_id: &str, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn add_to_per_user_sorted_set(
details: &PostDetails,
) -> Result<(), DynError>
pub async fn add_to_per_user_sorted_set( details: &PostDetails, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn remove_from_per_user_sorted_set(
author_id: &str,
post_id: &str,
) -> Result<(), DynError>
pub async fn remove_from_per_user_sorted_set( author_id: &str, post_id: &str, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn add_to_post_reply_sorted_set(
parent_post_key_parts: &[&str; 2],
author_id: &str,
reply_id: &str,
indexed_at: i64,
) -> Result<(), DynError>
pub async fn add_to_post_reply_sorted_set( parent_post_key_parts: &[&str; 2], author_id: &str, reply_id: &str, indexed_at: i64, ) -> Result<(), DynError>
Adds the post response to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn remove_from_post_reply_sorted_set(
parent_post_key_parts: &[&str; 2],
author_id: &str,
reply_id: &str,
) -> Result<(), DynError>
pub async fn remove_from_post_reply_sorted_set( parent_post_key_parts: &[&str; 2], author_id: &str, reply_id: &str, ) -> Result<(), DynError>
Adds the post response to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn add_to_replies_per_user_sorted_set(
details: &PostDetails,
) -> Result<(), DynError>
pub async fn add_to_replies_per_user_sorted_set( details: &PostDetails, ) -> Result<(), DynError>
Adds the post to a Redis sorted set of replies per author using the indexed_at timestamp as the score.
Sourcepub async fn remove_from_replies_per_user_sorted_set(
author_id: &str,
post_id: &str,
) -> Result<(), DynError>
pub async fn remove_from_replies_per_user_sorted_set( author_id: &str, post_id: &str, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn add_to_bookmarks_sorted_set(
bookmark: &Bookmark,
bookmarker_id: &str,
post_id: &str,
author_id: &str,
) -> Result<(), DynError>
pub async fn add_to_bookmarks_sorted_set( bookmark: &Bookmark, bookmarker_id: &str, post_id: &str, author_id: &str, ) -> Result<(), DynError>
Adds a bookmark to Redis sorted set using the indexed_at timestamp as the score.
Sourcepub async fn remove_from_bookmarks_sorted_set(
bookmarker_id: &str,
post_id: &str,
author_id: &str,
) -> Result<(), DynError>
pub async fn remove_from_bookmarks_sorted_set( bookmarker_id: &str, post_id: &str, author_id: &str, ) -> Result<(), DynError>
Remove a bookmark from Redis sorted
Sourcepub async fn add_to_engagement_sorted_set(
counts: &PostCounts,
author_id: &str,
post_id: &str,
) -> Result<(), DynError>
pub async fn add_to_engagement_sorted_set( counts: &PostCounts, author_id: &str, post_id: &str, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the total engagement as the score.
pub async fn delete_from_engagement_sorted_set( author_id: &str, post_id: &str, ) -> Result<(), DynError>
pub async fn update_index_score( author_id: &str, post_id: &str, score_action: ScoreAction, ) -> Result<(), DynError>