pub struct TagUser(pub Vec<String>);Tuple Fields
0: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for TagUser
impl<'de> Deserialize<'de> for TagUser
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl RedisOps for TagUser
impl RedisOps for TagUser
Sourcefn prefix<'async_trait>() -> Pin<Box<dyn Future<Output = String> + Send + 'async_trait>>
fn prefix<'async_trait>() -> Pin<Box<dyn Future<Output = String> + Send + 'async_trait>>
Provides a prefix string for the Redis key. Read more
Sourcefn put_index_json<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
key_parts: &'life1 [&'life2 str],
prefix: Option<String>,
expiration: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn put_index_json<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
key_parts: &'life1 [&'life2 str],
prefix: Option<String>,
expiration: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Sets the data in Redis using the provided key parts. Read more
Sourcefn try_from_index_json<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<Self>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn try_from_index_json<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<Self>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves data from Redis using the provided key parts. Read more
Sourcefn try_from_index_multiple_json<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 [&'life2 str]],
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<Self>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn try_from_index_multiple_json<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 [&'life2 str]],
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<Self>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Retrieves multiple JSON objects from Redis using the provided key parts. Read more
Sourcefn put_multiple_json_indexes<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 [&'life2 str]],
collection: Vec<Option<Self>>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn put_multiple_json_indexes<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 [&'life2 str]],
collection: Vec<Option<Self>>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Stores multiple key-value pairs in Redis, where each key is constructed from the provided key parts
and each value is an item from the given collection. Read more
Sourcefn remove_from_index_multiple_json<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 [&'life2 str]],
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn remove_from_index_multiple_json<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 [&'life2 str]],
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Removes multiple JSON objects from Redis using the provided key parts. Read more
Sourcefn modify_json_field<'life0, 'life1, 'life2, 'async_trait>(
key_parts: &'life0 [&'life1 str],
field: &'life2 str,
action: JsonAction,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn modify_json_field<'life0, 'life1, 'life2, 'async_trait>(
key_parts: &'life0 [&'life1 str],
field: &'life2 str,
action: JsonAction,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Modifies a numeric field in a Redis JSON object by either incrementing or decrementing it. Read more
Sourcefn put_index_list<'life0, 'life1, 'life2, 'async_trait, T>(
&'life0 self,
key_parts: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>
fn put_index_list<'life0, 'life1, 'life2, 'async_trait, T>( &'life0 self, key_parts: &'life1 [&'life2 str], ) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>
Adds elements to a Redis list using the provided key parts. Read more
Sourcefn try_from_index_list<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
skip: Option<usize>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn try_from_index_list<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
skip: Option<usize>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves a range of elements from a Redis list using the provided key parts. Read more
Sourcefn put_index_set<'life0, 'life1, 'life2, 'life3, 'async_trait>(
key_parts: &'life0 [&'life1 str],
values: &'life2 [&'life3 str],
expiration: Option<i64>,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn put_index_set<'life0, 'life1, 'life2, 'life3, 'async_trait>(
key_parts: &'life0 [&'life1 str],
values: &'life2 [&'life3 str],
expiration: Option<i64>,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Adds elements to a Redis set using the provided key parts. Read more
Sourcefn remove_from_index_set<'life0, 'life1, 'life2, 'async_trait, T>(
&'life0 self,
key_parts: &'life1 [&'life2 str],
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>
fn remove_from_index_set<'life0, 'life1, 'life2, 'async_trait, T>( &'life0 self, key_parts: &'life1 [&'life2 str], ) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>
Removes elements from a Redis set using the provided key parts. Read more
Sourcefn try_from_index_set<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
skip: Option<usize>,
limit: Option<usize>,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn try_from_index_set<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
skip: Option<usize>,
limit: Option<usize>,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves a range of elements from a Redis set using the provided key parts. Read more
Sourcefn check_set_member<'life0, 'life1, 'life2, 'async_trait>(
key_parts: &'life0 [&'life1 str],
member: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<(bool, bool), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn check_set_member<'life0, 'life1, 'life2, 'async_trait>(
key_parts: &'life0 [&'life1 str],
member: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<(bool, bool), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Checks if a member exists in a Redis set and if the set exists using the provided key parts. Read more
Sourcefn get_set_size<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
) -> Pin<Box<dyn Future<Output = Result<Option<usize>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_set_size<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
) -> Pin<Box<dyn Future<Output = Result<Option<usize>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves the size of a Redis set using the provided key parts. Read more
Sourcefn try_from_multiple_sets<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 str],
prefix: Option<String>,
member: Option<&'life2 str>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<(Vec<String>, usize, bool)>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn try_from_multiple_sets<'life0, 'life1, 'life2, 'async_trait>(
key_parts_list: &'life0 [&'life1 str],
prefix: Option<String>,
member: Option<&'life2 str>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<(Vec<String>, usize, bool)>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Fetches multiple sets from Redis using the specified key components. Read more
Sourcefn put_multiple_set_indexes<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
common_key: &'life0 [&'life1 str],
index: &'life2 [&'life3 str],
collections_refs: &'life4 [Vec<&'life5 str>],
prefix: Option<String>,
expiration: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
fn put_multiple_set_indexes<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'async_trait>(
common_key: &'life0 [&'life1 str],
index: &'life2 [&'life3 str],
collections_refs: &'life4 [Vec<&'life5 str>],
prefix: Option<String>,
expiration: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
Adds elements to multiple Redis sets using the provided keys and collections. Read more
Sourcefn try_get_random_from_index_set<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
count: isize,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn try_get_random_from_index_set<'life0, 'life1, 'async_trait>(
key_parts: &'life0 [&'life1 str],
count: isize,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves random elements from a Redis set using the provided key parts. Read more
Sourcefn check_sorted_set_member<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
prefix: Option<&'life0 str>,
key_parts: &'life1 [&'life2 str],
member: &'life3 [&'life4 str],
) -> Pin<Box<dyn Future<Output = Result<Option<isize>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn check_sorted_set_member<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
prefix: Option<&'life0 str>,
key_parts: &'life1 [&'life2 str],
member: &'life3 [&'life4 str],
) -> Pin<Box<dyn Future<Output = Result<Option<isize>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Checks if a member exists in a Redis sorted set and retrieves its score if it exists. Read more
Sourcefn put_index_sorted_set<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
key_parts: &'life0 [&'life1 str],
elements: &'life2 [(f64, &'life3 str)],
prefix: Option<&'life4 str>,
expiration: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn put_index_sorted_set<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
key_parts: &'life0 [&'life1 str],
elements: &'life2 [(f64, &'life3 str)],
prefix: Option<&'life4 str>,
expiration: Option<i64>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Adds elements to a Redis sorted set using the provided key parts. Read more
Sourcefn put_score_index_sorted_set<'life0, 'life1, 'life2, 'life3, 'async_trait>(
key_parts: &'life0 [&'life1 str],
member: &'life2 [&'life3 str],
score_mutation: ScoreAction,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn put_score_index_sorted_set<'life0, 'life1, 'life2, 'life3, 'async_trait>(
key_parts: &'life0 [&'life1 str],
member: &'life2 [&'life3 str],
score_mutation: ScoreAction,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Updates the score of a member in a Redis sorted set. Read more
Sourcefn remove_from_index_sorted_set<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
prefix: Option<&'life0 str>,
key_parts: &'life1 [&'life2 str],
items: &'life3 [&'life4 str],
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn remove_from_index_sorted_set<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
prefix: Option<&'life0 str>,
key_parts: &'life1 [&'life2 str],
items: &'life3 [&'life4 str],
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Removes elements from a Redis sorted set using the provided key parts. Read more
Sourcefn try_from_index_sorted_set<'life0, 'life1, 'life2, 'async_trait>(
key_parts: &'life0 [&'life1 str],
start: Option<f64>,
end: Option<f64>,
skip: Option<usize>,
limit: Option<usize>,
sorting: SortOrder,
prefix: Option<&'life2 str>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<(String, f64)>>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn try_from_index_sorted_set<'life0, 'life1, 'life2, 'async_trait>(
key_parts: &'life0 [&'life1 str],
start: Option<f64>,
end: Option<f64>,
skip: Option<usize>,
limit: Option<usize>,
sorting: SortOrder,
prefix: Option<&'life2 str>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<(String, f64)>>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Retrieves a range of elements from a Redis sorted set using the provided key parts. Read more
Sourcefn try_from_index_sorted_set_lex<'life0, 'life1, 'life2, 'life3, 'async_trait>(
key_parts: &'life0 [&'life1 str],
min: &'life2 str,
max: &'life3 str,
skip: Option<usize>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn try_from_index_sorted_set_lex<'life0, 'life1, 'life2, 'life3, 'async_trait>(
key_parts: &'life0 [&'life1 str],
min: &'life2 str,
max: &'life3 str,
skip: Option<usize>,
limit: Option<usize>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<String>>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Retrieves a lexicographical range of elements from a Redis sorted set using the provided key parts. Read more
Sourceimpl TagCollection for TagUser
impl TagCollection for TagUser
Sourcefn get_tag_prefix<'a>() -> [&'a str; 2]
fn get_tag_prefix<'a>() -> [&'a str; 2]
Returns the unique key parts used to identify a tag in the Redis database
Sourcefn get_by_id<'life0, 'life1, 'life2, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
skip_tags: Option<usize>,
limit_tags: Option<usize>,
limit_taggers: Option<usize>,
viewer_id: Option<&'life2 str>,
depth: Option<u8>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<TagDetails>>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn get_by_id<'life0, 'life1, 'life2, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
skip_tags: Option<usize>,
limit_tags: Option<usize>,
limit_taggers: Option<usize>,
viewer_id: Option<&'life2 str>,
depth: Option<u8>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<TagDetails>>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Retrieves tag details for a given user ID with optional parameters for filtering and limits. Read more
Sourcefn get_from_index<'life0, 'life1, 'life2, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
viewer_id: Option<&'life2 str>,
skip_tags: Option<usize>,
limit_tags: Option<usize>,
limit_taggers: Option<usize>,
is_cache: bool,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<TagDetails>>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn get_from_index<'life0, 'life1, 'life2, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
viewer_id: Option<&'life2 str>,
skip_tags: Option<usize>,
limit_tags: Option<usize>,
limit_taggers: Option<usize>,
is_cache: bool,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<TagDetails>>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Tries to retrieve the tag collection from multiple index in Redis. Read more
Sourcefn get_from_graph<'life0, 'life1, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
depth: Option<u8>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<TagDetails>>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_from_graph<'life0, 'life1, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
depth: Option<u8>,
) -> Pin<Box<dyn Future<Output = Result<Option<Vec<TagDetails>>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Retrieves the tag collection from the graph database if it is not found in the index. Read more
Sourcefn put_to_index<'life0, 'life1, 'life2, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
tags: &'life2 [TagDetails],
is_cache: bool,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn put_to_index<'life0, 'life1, 'life2, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
tags: &'life2 [TagDetails],
is_cache: bool,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Adds the retrieved tags to a sorted set and a set in Redis. Read more
Sourcefn update_index_score<'life0, 'life1, 'life2, 'async_trait>(
author_id: &'life0 str,
extra_param: Option<&'life1 str>,
label: &'life2 str,
score_action: ScoreAction,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn update_index_score<'life0, 'life1, 'life2, 'async_trait>(
author_id: &'life0 str,
extra_param: Option<&'life1 str>,
label: &'life2 str,
score_action: ScoreAction,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Updates the score of a label in the appropriate Redis index (user or post) based on the given score action. Read more
Sourcefn add_tagger_to_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
author_id: &'life0 str,
extra_param: Option<&'life1 str>,
tagger_user_id: &'life2 str,
tag_label: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn add_tagger_to_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
author_id: &'life0 str,
extra_param: Option<&'life1 str>,
tagger_user_id: &'life2 str,
tag_label: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Adds a tagger (user) to the appropriate Redis index for a specified tag label. Read more
Sourcefn put_to_graph<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
tagger_user_id: &'life0 str,
tagged_user_id: &'life1 str,
extra_param: Option<&'life2 str>,
tag_id: &'life3 str,
label: &'life4 str,
indexed_at: i64,
) -> Pin<Box<dyn Future<Output = Result<OperationOutcome, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn put_to_graph<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
tagger_user_id: &'life0 str,
tagged_user_id: &'life1 str,
extra_param: Option<&'life2 str>,
tag_id: &'life3 str,
label: &'life4 str,
indexed_at: i64,
) -> Pin<Box<dyn Future<Output = Result<OperationOutcome, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Inserts a tag relationship into the graph database. Read more
Sourcefn reindex<'life0, 'life1, 'async_trait>(
author_id: &'life0 str,
extra_param: Option<&'life1 str>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn reindex<'life0, 'life1, 'async_trait>(
author_id: &'life0 str,
extra_param: Option<&'life1 str>,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Reindexes tags for a given author by retrieving data from the graph database and updating the index. Read more
Sourcefn del_from_graph<'life0, 'life1, 'async_trait>(
user_id: &'life0 str,
tag_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<(Option<String>, Option<String>, Option<String>, String)>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
fn del_from_graph<'life0, 'life1, 'async_trait>(
user_id: &'life0 str,
tag_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<Option<(Option<String>, Option<String>, Option<String>, String)>, DynError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Deletes a tag relationship between a user and a tagged target (User or Post) in the graph database. Read more
Sourcefn read_graph_query(user_id: &str, extra_param: Option<&str>) -> Query
fn read_graph_query(user_id: &str, extra_param: Option<&str>) -> Query
Creates a Neo4j query to retrieve tags Read more
Sourcefn create_sorted_set_key_parts<'a>(
user_id: &'a str,
extra_param: Option<&'a str>,
is_cache: bool,
) -> Vec<&'a str>
fn create_sorted_set_key_parts<'a>( user_id: &'a str, extra_param: Option<&'a str>, is_cache: bool, ) -> Vec<&'a str>
Constructs the index for a sorted set in Redis based on the user key and an optional extra parameter. Read more
Sourceimpl TaggersCollection for TagUser
impl TaggersCollection for TagUser
Sourcefn get_tagger_by_id<'life0, 'life1, 'life2, 'life3, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
label: &'life2 str,
pagination: Pagination,
viewer_id: Option<&'life3 str>,
depth: Option<u8>,
) -> Pin<Box<dyn Future<Output = Result<Option<TaggersTuple>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn get_tagger_by_id<'life0, 'life1, 'life2, 'life3, 'async_trait>(
user_id: &'life0 str,
extra_param: Option<&'life1 str>,
label: &'life2 str,
pagination: Pagination,
viewer_id: Option<&'life3 str>,
depth: Option<u8>,
) -> Pin<Box<dyn Future<Output = Result<Option<TaggersTuple>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Retrieves taggers associated with a given user ID and label. Read more
fn get_from_index<'life0, 'life1, 'async_trait>(
key_parts: Vec<&'life0 str>,
viewer_id: Option<&'life1 str>,
skip: Option<usize>,
limit: Option<usize>,
prefix: Option<String>,
) -> Pin<Box<dyn Future<Output = Result<Option<TaggersTuple>, DynError>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn create_label_index<'a>(
user_id: &'a str,
extra_param: Option<&'a str>,
label: &'a str,
is_cache: bool,
) -> Vec<&'a str>
fn create_label_index<'a>( user_id: &'a str, extra_param: Option<&'a str>, label: &'a str, is_cache: bool, ) -> Vec<&'a str>
Constructs an index key based on user key, an optional extra parameter and a tag label. Read more
Sourcefn del_from_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
author_id: &'life1 str,
extra_param: Option<&'life2 str>,
tag_label: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn del_from_index<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
author_id: &'life1 str,
extra_param: Option<&'life2 str>,
tag_label: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<(), DynError>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Remove a tagger from the label tagger list