pub struct UserCounts {
pub tagged: u32,
pub tags: u32,
pub unique_tags: u32,
pub posts: u32,
pub replies: u32,
pub following: u32,
pub followers: u32,
pub friends: u32,
pub bookmarks: u32,
}Expand description
Represents total counts of relationships of a user.
Fields
tagged: u32posts: u32replies: u32following: u32followers: u32friends: u32bookmarks: u32Implementations
Sourceimpl UserCounts
impl UserCounts
Sourcepub async fn get_by_id(user_id: &str) -> Result<Option<UserCounts>, DynError>
pub async fn get_by_id(user_id: &str) -> Result<Option<UserCounts>, DynError>
Retrieves counts by user ID, first trying to get from Redis, then from Neo4j if not found.
Sourcepub async fn get_from_graph(
user_id: &str,
) -> Result<Option<UserCounts>, DynError>
pub async fn get_from_graph( user_id: &str, ) -> Result<Option<UserCounts>, DynError>
Retrieves the counts from Neo4j.
pub async fn get_from_index( user_id: &str, ) -> Result<Option<UserCounts>, DynError>
pub async fn put_to_index(&self, user_id: &str) -> Result<(), DynError>
pub async fn update_index_field( author_id: &str, field: &str, action: JsonAction, ) -> Result<(), DynError>
Sourcepub async fn update(
user_id: &str,
field: &str,
action: JsonAction,
tag_label: Option<&str>,
) -> Result<(), DynError>
pub async fn update( user_id: &str, field: &str, action: JsonAction, tag_label: Option<&str>, ) -> Result<(), DynError>
Updates a user’s counts index field and conditionally updates ranking sets based on follower, tag, or post counts.
Arguments
user_id- The unique identifier of the user whose index field is being updated.field- The name of the user-related field to update (e.g.,"followers","tags","posts").action- The action to perform on the field (increment or decrement).tag_label- An optional tag label used to check membership in the user’s tag-related sorted set. Important if we want to update the unique_tags field
Behavior
- Conditional Update Based on
tag_label - Update User Counts Index
- Update Ranking Sets for Specific Fields
pub async fn reindex(author_id: &str) -> Result<(), DynError>
pub async fn delete(user_id: &str) -> Result<(), DynError>