pub struct UserStream(pub Vec<UserView>);Tuple Fields
0: Vec<UserView>Implementations
Sourceimpl UserStream
impl UserStream
pub fn extend(&mut self, user_stream: UserStream)
pub async fn get_by_id( input: UserStreamInput, viewer_id: Option<String>, depth: Option<u8>, ) -> Result<Option<Self>, DynError>
pub async fn get_from_username_search( username: &str, viewer_id: Option<&str>, skip: Option<usize>, limit: Option<usize>, ) -> Result<Option<Self>, DynError>
pub async fn from_listed_user_ids( user_ids: &[String], viewer_id: Option<&str>, depth: Option<u8>, ) -> Result<Option<Self>, DynError>
Sourcepub async fn add_to_most_followed_sorted_set(
user_id: &str,
counts: &UserCounts,
) -> Result<(), DynError>
pub async fn add_to_most_followed_sorted_set( user_id: &str, counts: &UserCounts, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the follower counts as score.
Sourcepub async fn add_to_influencers_sorted_set(
user_id: &str,
counts: &UserCounts,
) -> Result<(), DynError>
pub async fn add_to_influencers_sorted_set( user_id: &str, counts: &UserCounts, ) -> Result<(), DynError>
Adds the post to a Redis sorted set using the follower counts as score.
Sourcepub async fn get_recommended_ids(
user_id: &str,
limit: Option<usize>,
) -> Result<Option<Vec<String>>, DynError>
pub async fn get_recommended_ids( user_id: &str, limit: Option<usize>, ) -> Result<Option<Vec<String>>, DynError>
Retrieves recommended user IDs based on the specified criteria.
pub async fn get_user_list_from_source( input: UserStreamInput, ) -> Result<Option<Vec<String>>, DynError>