pub struct UserDetails {
pub name: String,
pub bio: Option<String>,
pub id: PubkyId,
pub links: Option<Vec<PubkyAppUserLink>>,
pub status: Option<String>,
pub image: Option<String>,
pub indexed_at: i64,
}Expand description
Represents user data with name, bio, image, links, and status.
Fields
name: Stringbio: Option<String>id: PubkyIdlinks: Option<Vec<PubkyAppUserLink>>status: Option<String>image: Option<String>indexed_at: i64Implementations
Sourceimpl UserDetails
impl UserDetails
Sourcepub async fn get_by_id(user_id: &str) -> Result<Option<Self>, DynError>
pub async fn get_by_id(user_id: &str) -> Result<Option<Self>, DynError>
Retrieves details by user ID, first trying to get from Redis, then from Neo4j if not found.
pub async fn from_homeserver( homeserver_user: PubkyAppUser, user_id: &PubkyId, ) -> Result<Self, DynError>
pub async fn delete(user_id: &str) -> Result<(), DynError>